<template>
    <div ref="overlay" :class="['overlay-box', dialogVisible ? 'overlay-show' : '']" v-if="dialogVisible">
        <div class="content-box" :style="{ overflow: loading ? 'hidden' : 'auto' }" v-loading="loading"
            element-loading-text="加载中..." element-loading-spinner="el-icon-loading"
            element-loading-background="rgba(255, 255, 255, 1)">
            <div class="pdf-box" v-if="fileType === 'pdf'">
                <pdf v-for="i in pageTotalNum" :key="i" ref="pdf" :src="pdfSrc" :page="i"
                    @page-loaded="pageLoaded($event)" @error="pdfError($event)">
                </pdf>
            </div>
            <iframe v-else :src="pdfSrc" class="pdf__iframe" align="middle"
                content="width=device-width, initial-scale=1.0, user-scalable=no"></iframe>
        </div>
        <div class="close-btn" @click="close">
        </div>
    </div>
</template>

<script>
import req from '@/request.js'
import pdf from 'vue-pdf'
const portal = window.context.portal
export default {
    name: 'FilePreview',
    components: {
        pdf,
    },
    props: {
        appendToBody: {
            type: Boolean,
            default: false,
        },
    },
    data() {
        return {
            dialogVisible: false,
            fileType: '', //1、图片，2、word，3、excel, 4、pdf，
            previewUrl: '',
            loading: false,
            pageTotalNum: 1,
            pdfSrc: '',
            fileId: ''
        }
    },
    methods: {
        open(id) {
            this.loading = true
            if (this.fileId !== id) {
                this.fileId = id
                this.pdfSrc = ''
                req.get(this.previewUrl).then(res => {
                    if (res.data) {
                        let resurl = res.data.currentUrl || res.data.pdfUrl || res.data.TxtUrl
                        this.fileType = res.data.result
                        req.get(`${portal}${resurl}`, 'arraybuffer').then(
                            (response) => {
                                let type = response.headers['content-type'].split(';')
                                this.pdfSrc = window.URL.createObjectURL(
                                    new Blob([response.data], {
                                        type: res.data.result === 'pdf' ? 'application/pdf' : type[0],
                                    })
                                )
                                if (res.data.result !== 'pdf') {
                                    this.getIframe()
                                } else {
                                    this.loading = false
                                }
                            })
                    } else {
                        this.$message.error('附件预览失败')
                    }
                })
            } else {
                if (this.fileType !== 'pdf') {
                    setTimeout(() => {
                        this.getIframe()
                    })
                } else {
                    setTimeout(() => {
                        this.loading = false
                    }, 1000)
                }
            }
            this.dialogVisible = true
        },
        getIframe() {
            let iframe = document.querySelector('.pdf__iframe')
            let iwindow = iframe.contentWindow;
            iframe.addEventListener('load', function () {
                let idoc = iwindow.document;
                let img = idoc.getElementsByTagName('img')[0];
                if (img) {
                    img.style.width = '100%';
                }
            })
            setTimeout(() => {
                this.loading = false
            }, 800)
        },
        // 页面加载完成回调函数，其中e为当前页数
        pageLoaded(e) {
            this.getNumPages()
            this.loading = false
        },
        // 获取pdf总页数
        getNumPages() {
            let loadingTask = pdf.createLoadingTask(this.pdfSrc)
            loadingTask.promise
                .then((pdf) => {
                    this.pageTotalNum = pdf.numPages
                })
                .catch((err) => {
                    console.error('pdf 加载失败', err)
                })
        },
        //
        pdfError(error) {
            this.loading = false
            this.$message.error(error)
        },
        close() {
            this.dialogVisible = false
        },
    },
}
</script>
<style lang="scss">
.pdf__iframe {
    width: 100%;
    height: 100%;
    border: 0;

    /deep/img {
        width: 100% !important;
    }
}
</style>
<style lang="scss" scoped>
iframe::-webkit-scrollbar {
    width: 10px;
}

iframe::-webkit-scrollbar {
    height: 10px;
}

iframe::-webkit-scrollbar-thumb {
    background-color: blue;
}

iframe::-webkit-scrollbar-thumb {
    border-radius: 5px;
}

iframe::-webkit-scrollbar-track {
    background-color: gray;
}

.overlay-box {
    position: fixed;
    top: 0;
    left: 0;
    right: 0;
    // width: inherit;
    height: 100%;
    padding: 0% 20%;
    background-color: rgba(0, 0, 0, .5);
    z-index: 999999;
    transition: all .5s;
    transform: scale(0);


    .content-box {
        width: 100%;
        height: 100%;
        background: #fff;
        overflow: auto;
    }

    .close-btn {
        position: absolute;
        right: 0;
        top: 0;
        width: 50px;
        height: 50px;
        border-bottom-left-radius: 100%;
        background-color: rgba(0, 0, 0, .5);
        cursor: pointer;

        &:hover {
            background-color: rgba(0, 0, 0, 1);
        }

        &::after {
            position: absolute;
            left: 50%;
            top: 50%;
            transform: translate(-20%, -60%);
            content: '';
            width: 18px;
            height: 18px;
            background: url('../../assets/img/icon_clear.svg') no-repeat;
            background-size: cover;
        }
    }
}

@keyframes animateName {
    0% {
        opacity: 0;
        transform: scale(0);
    }

    100% {
        opacity: 1;
        transform: scale(1);
    }
}

.overlay-show {
    animation-name: animateName;
    animation-duration: .3s;
    animation-fill-mode: forwards;
}
</style>
